@@ -1,8 +1,7 @@
 # pylint: disable=C0321,C0103,C0301,E1305,E1121,C0302,C0330,C0111,W0613,W0611,R1705
 # -*- coding: utf-8 -*-
-import os, sys, time, datetime,inspect, json, yaml
-import logging, os, pandas as pd, numpy as np
-from sklearn.model_selection import train_test_split
+import os, sys, time, datetime,inspect, json, yaml, pandas as pd, numpy as np
+from sklearn.model_selection import train_test_split,
 from pathlib import Path
 
 ####################################################################################################
@@ -11,25 +10,47 @@ verbosity = 3
 def log(*s):
     if verbosity>= 1: print(*s, flush=True)
 
-
 def log2(*s):
     if verbosity>= 1: print(*s, flush=True)
 
 def log3(*s):
     if verbosity>= 1: print(*s, flush=True)
 
+
 ####################################################################################################
 
 
-def benchmark(config='', dmin=5, dmax=6):
+def dataset_classifier_XXXXX(nrows=500, **kw):
+
+    ....
+
+    pars = { 'colnum': colnum, 'colcat': colcat, "coly": coly, 'info': '' }
+    return df, pars  
+
+
+
+
+
+
+
+
+
+
+####################################################################################################
+def split(df):
+    X,y = df
+    X_train_full, X_test, y_train_full, y_test = train_test_split(X, y, test_size=0.05, random_state=2021)
+    X_train, X_valid, y_train, y_valid         = train_test_split(X_train_full, y_train_full, random_state=2021)
+
+
+
+def dataset_classifier_pmlb(name='', return_X_y=False):
     from pmlb import fetch_data, classification_dataset_names
 
-    for classification_dataset in classification_dataset_names[dmin:dmax]:
-        X, y = fetch_data(classification_dataset, return_X_y=True)
-
-        X_train_full, X_test, y_train_full, y_test = train_test_split(X, y, test_size=0.05, random_state=2021)
-        X_train, X_valid, y_train, y_valid         = train_test_split(X_train_full, y_train_full, random_state=2021)
+    ds = classification_dataset_names[name]:
 
+    df = fetch_data(ds, return_X_y= return_X_y)
+    return df, pars
 
 
 
@@ -155,6 +176,71 @@ def git_current_hash(mode='full'):
 
 
 
+def fetch_dataset(url_dataset, path_target=None, file_target=None):
+    """Fetch dataset from a given URL and save it.
+
+    Currently `github`, `gdrive` and `dropbox` are the only supported sources of
+    data. Also only zip files are supported.
+
+    :param url_dataset:   URL to send
+    :param path_target:   Path to save dataset
+    :param file_target:   File to save dataset
+
+    """
+    log("###### Download ##################################################")
+    from tempfile import mktemp, mkdtemp
+    from urllib.parse import urlparse, parse_qs
+    import pathlib
+    fallback_name        = "features"
+    download_path        = path_target
+    supported_extensions = [ ".zip" ]
+
+    if path_target is None:
+        path_target   = mkdtemp(dir=os.path.curdir)
+        download_path = path_target
+    else:
+        pathlib.Path(path_target).mkdir(parents=True, exist_ok=True)
+
+    if file_target is None:
+        file_target = fallback_name # mktemp(dir="")
+
+
+    if "github.com" in url_dataset:
+        """
+                # https://github.com/arita37/dsa2_data/raw/main/input/titanic/train/features.zip
+              https://github.com/arita37/dsa2_data/raw/main/input/titanic/train/features.zip            
+              https://raw.githubusercontent.com/arita37/dsa2_data/main/input/titanic/train/features.csv            
+              https://raw.githubusercontent.com/arita37/dsa2_data/tree/main/input/titanic/train/features.zip             
+              https://github.com/arita37/dsa2_data/blob/main/input/titanic/train/features.zip
+                 
+        """
+        # urlx = url_dataset.replace(  "github.com", "raw.githubusercontent.com" )
+        urlx = url_dataset.replace("/blob/", "/raw/")
+        urlx = urlx.replace("/tree/", "/raw/")
+        log(urlx)
+
+        urlpath = urlx.replace("https://github.com/", "github_")
+        urlpath = urlpath.split("/")
+        fname = urlpath[-1]  ## filaneme
+        fpath = "-".join(urlpath[:-1])[:-1]   ### prefix path normalized
+        assert "." in fname, f"No filename in the url {urlx}"
+
+        os.makedirs(download_path + "/" + fpath, exist_ok= True)
+        full_filename = os.path.abspath( download_path + "/" + fpath + "/" + fname )
+        log('#### Download saving in ', full_filename)
+
+        import requests
+        with requests.Session() as s:
+            res = s.get(urlx)
+            if res.ok:
+                print(res.ok)
+                with open(full_filename, "wb") as f:
+                    f.write(res.content)
+            else:
+                raise res.raise_for_status()
+        return full_filename
+
+
 
 
 
